==> jc-1.4.0.tar.gz: gnu/regexp/RETokenRange.h <==
// final class gnu.regexp.RETokenRange

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class 7525fd58577dcdf8 gnu_regexp_RETokenRange
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenRange_H_
#define _JC_gnu_regexp_RETokenRange_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenRange$sub_refs	_jc_gnu_regexp_RETokenRange$sub_refs;
typedef struct _jc_gnu_regexp_RETokenRange$sub_nonrefs	_jc_gnu_regexp_RETokenRange$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenRange$refs	_jc_gnu_regexp_RETokenRange$refs;
typedef struct _jc_gnu_regexp_RETokenRange$nonrefs	_jc_gnu_regexp_RETokenRange$nonrefs;
typedef struct _jc_gnu_regexp_RETokenRange$object	_jc_gnu_regexp_RETokenRange$object;

typedef const struct _jc_gnu_regexp_RETokenRange$vmethods	_jc_gnu_regexp_RETokenRange$vmethods;
typedef const struct _jc_gnu_regexp_RETokenRange$vtable	_jc_gnu_regexp_RETokenRange$vtable;
typedef const struct _jc_gnu_regexp_RETokenRange$vtype	_jc_gnu_regexp_RETokenRange$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenRange$method$_init$f5242f549d63ece5(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *, jint, jchar, jchar, jboolean);

// Virtual methods
extern void _jc_gnu_regexp_RETokenRange$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *, struct _jc_java_lang_StringBuffer$object *);
extern jint _jc_gnu_regexp_RETokenRange$method$getMinimumLength$13aeed906e65d975(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *);
extern jboolean _jc_gnu_regexp_RETokenRange$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenRange$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenRange$method_info$getMinimumLength$13aeed906e65d975;
extern _jc_method _jc_gnu_regexp_RETokenRange$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenRange$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *, struct _jc_java_lang_StringBuffer$object *);
	jint	(*getMinimumLength$13aeed906e65d975)(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *);
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);
};

// Vtable
struct _jc_gnu_regexp_RETokenRange$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenRange$vmethods	gnu_regexp_RETokenRange;
};

// Vtype
struct _jc_gnu_regexp_RETokenRange$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenRange$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenRange$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenRange$refs {
    _jc_gnu_regexp_RETokenRange$sub_refs	gnu_regexp_RETokenRange;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenRange$sub_nonrefs {
	jchar	lo;
	jchar	hi;
	jboolean	insens;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenRange$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenRange$sub_nonrefs	gnu_regexp_RETokenRange;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenRange$object {
	_jc_gnu_regexp_RETokenRange$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenRange$vtype	*vtype;
	_jc_gnu_regexp_RETokenRange$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenRange$vtype _jc_gnu_regexp_RETokenRange$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenRange, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenRange$class_object;

#endif	/* _JC_gnu_regexp_RETokenRange_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/RETokenRange.h <==
// final class gnu.regexp.RETokenRange

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class 7525fd58577dcdf8 gnu_regexp_RETokenRange
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenRange_H_
#define _JC_gnu_regexp_RETokenRange_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenRange$sub_refs	_jc_gnu_regexp_RETokenRange$sub_refs;
typedef struct _jc_gnu_regexp_RETokenRange$sub_nonrefs	_jc_gnu_regexp_RETokenRange$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenRange$refs	_jc_gnu_regexp_RETokenRange$refs;
typedef struct _jc_gnu_regexp_RETokenRange$nonrefs	_jc_gnu_regexp_RETokenRange$nonrefs;
typedef struct _jc_gnu_regexp_RETokenRange$object	_jc_gnu_regexp_RETokenRange$object;

typedef const struct _jc_gnu_regexp_RETokenRange$vmethods	_jc_gnu_regexp_RETokenRange$vmethods;
typedef const struct _jc_gnu_regexp_RETokenRange$vtable	_jc_gnu_regexp_RETokenRange$vtable;
typedef const struct _jc_gnu_regexp_RETokenRange$vtype	_jc_gnu_regexp_RETokenRange$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenRange$method$_init$f5242f549d63ece5(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *, jint, jchar, jchar, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_regexp_RETokenRange$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_regexp_RETokenRange$method$getMinimumLength$13aeed906e65d975(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_RETokenRange$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenRange$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenRange$method_info$getMinimumLength$13aeed906e65d975;
extern _jc_method _jc_gnu_regexp_RETokenRange$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenRange$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
	jint	(*getMinimumLength$13aeed906e65d975)(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *) _JC_JCNI_ATTR;
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenRange$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_RETokenRange$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenRange$vmethods	gnu_regexp_RETokenRange;
};

// Vtype
struct _jc_gnu_regexp_RETokenRange$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenRange$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenRange$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenRange$refs {
    _jc_gnu_regexp_RETokenRange$sub_refs	gnu_regexp_RETokenRange;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenRange$sub_nonrefs {
	jchar	lo;
	jchar	hi;
	jboolean	insens;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenRange$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenRange$sub_nonrefs	gnu_regexp_RETokenRange;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenRange$object {
	_jc_gnu_regexp_RETokenRange$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenRange$vtype	*vtype;
	_jc_gnu_regexp_RETokenRange$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenRange$vtype _jc_gnu_regexp_RETokenRange$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenRange, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenRange$class_object;

#endif	/* _JC_gnu_regexp_RETokenRange_H_ */
